@@ -141,6 +141,11 @@ class OracleStoreValidationResultsAction(ValidationAction):
         ### UNCOMMENT THE FOLLOWING 2 LINES OF CODE TO TEST THIS PLUGIN IN YOUR LOCAL FILESYSTEM
         # with open(file_key, "w") as outfile:
         #     outfile.write(json_object)
+
+        # check for existing table if not exist create new one
+        self.create_table_if_not_exist()
+
+        # upoload results data to the oracledb
         self.set(file_name, meta, evaluation_parameters, statistics, success, results)
     
     @property
@@ -172,7 +177,16 @@ class OracleStoreValidationResultsAction(ValidationAction):
         return connection
 
     def set(self, key, meta, eval, stat, succ, results, content_encoding="utf-8", **kwargs):
+        """
+        Method to upload validation data into the oracledb
 
+        key: table primary key
+        meta: validation result meta field
+        eval: validation Evaluations result
+        stat: validation stat results
+        success: Validation success or fails in boolean
+        results: validation results data
+        """
         import oracledb
 
         sql = ('insert into {t}(BATCH_KEY, META, EVALUATION_PARAMETERS, STATISTICS, SUCCESS, RESULT) '
@@ -187,4 +201,34 @@ class OracleStoreValidationResultsAction(ValidationAction):
                 self._database_client.commit()
             except oracledb.Error as error:
                 logger.error('Error occurred:')
-                logger.fatal(error)
\ No newline at end of file
+                logger.fatal(error)
+
+    def create_table_if_not_exist(self):
+        """
+        Method that checks if Table already exists or not
+        If not, It will create a new table in oracledb
+        """
+        import oracledb
+        
+        query = f'select * from {self.table_name}'
+        create_table_query = (
+                              f"CREATE TABLE  {self.table_name}"
+                              "( BATCH_KEY VARCHAR2(100) NOT NULL "
+                              ", META CLOB "
+                              ", EVALUATION_PARAMETERS CLOB "
+                              ", STATISTICS CLOB "
+                              ", SUCCESS VARCHAR2(10) "
+                              ", RESULT CLOB )"
+                            )
+
+        with self._database_client.cursor() as cursor:
+            try:
+                cursor.execute(query)
+            except oracledb.Error as error:
+                if "ORA-00942: table or view does not exist" == str(error):
+                    logger.warning("Table {} doesn't exist ,  CREATING TABLE ...".format(self.table_name))
+                # create a table here
+                cursor.execute(create_table_query)
+                logger.warning("TABLE {} SUCCESSFULLY CREATED.".format(self.table_name))
+            except Exception as error:
+                logger.error(error)
\ No newline at end of file
